use strict;
use warnings;

# This test was generated for <lib/Dist/Zilla/Plugin/Test/Compile/PerFile.pm>
# using by Dist::Zilla::Plugin::Test::Compile::PerFile ( Test::Compile::PerFile ) version 0.001000
# with template 01-basic.t.tpl

use Test::More 0.89 tests => 1;

require_ok("lib/Dist/Zilla/Plugin/Test/Compile/PerFile.pm");

